==> HostCMS-6.1.7.tar: modules/admin/form/action/i18n/ru.php <==
<?php

/**
 * Admin forms.
 *
 * @package HostCMS 6\Admin
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2014 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Действия формы центра администрирования',
	'action_lng_name' => '<acronym title="Название действия формы центра администрирования">Название действия</acronym>',
	'action_lng_description' => '<acronym title="Описание действия формы центра администрирования">Описание действия</acronym>',
	
	'show_form_action_title' => 'Действия формы центра администрирования "%s"',
	
	'apply_success' => 'Данные для действия успешно обновлены.',
	'apply_error' => 'Ошибка! Данные для действия не изменены.',

	'markDeleted_success' => 'Действие успешно удалено!',
	'markDeleted_error' => 'Ошибка! Действие формы не удалено!',

	'copy_success' => 'Действие успешно скопировано!',
	'copy_error' => 'Ошибка! Действие формы не скопировано!',
	
	'show_form_action_menu_add_new_top' => 'Действие',
	'show_form_action_menu_add_new' => 'Добавить',
	
	// Форма редактирования действий формы центра администрирования.
	'form_add_forms_event_title' => 'Добавление действия формы центра администрирования',
	'form_edit_forms_event_title' => 'Редактирование действия формы центра администрирования "%s"',

	'admin_form_tab_0' => 'Название',
	'confirm' => '<acronym title="Запрашивать подтверждение перед выполнением действия">Запрашивать подтверждение</acronym>',
	'name' => '<acronym title="Имя функции-обработчика действия">Функция-обработчик</acronym>',
	'sorting' => '<acronym title="Порядок сортировки для действия">Порядок сортировки</acronym>',
	'picture' => '<acronym title="Изображение для действия в списке действий, например /admin/images/edit.gif">Изображение</acronym>',
	'icon' => '<acronym title="CSS-стиля пиктограммы для действия в списке действий, например pencil">Пиктограмма</acronym>',
	'color' => '<acronym title="Название CSS-стиля, определяющего цвет действия в списке действий, например success">Цвет</acronym>',
	'dataset' => '<acronym title="Индекс набора данных для действия, -1 &mdash; действие для всех наборов данных">Индекс набора данных</acronym>',
	'single' => '<acronym title="Отображать действие в правом блоке со списком действий">Отображать в списке действий</acronym>',
	'group' => '<acronym title="Отображать действие в списке групповых операций">Групповая операция</acronym>',

	'admin_form_id' => 'Идентификатор формы центра администрирования',
	'id' => 'Идентификатор поля формы',
	
	'edit_success' => 'Действие формы добавлено!',
	'edit_error' => 'Ошибка! Действие формы не добавлено!',
	
	'form_event_menu_admin_form_action' => 'Список действий формы "%s"',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
);

==> HostCMS-6.8.6.tar: modules/admin/form/action/i18n/ru.php <==
<?php

/**
 * Admin forms.
 *
 * @package HostCMS
 * @subpackage Admin
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Действия формы центра администрирования',
	'action_lng_name' => 'Название действия',
	'action_lng_description' => 'Описание действия',
	
	'show_form_action_title' => 'Действия формы центра администрирования "%s"',
	
	'apply_success' => 'Данные для действия успешно обновлены.',
	'apply_error' => 'Ошибка! Данные для действия не изменены.',

	'markDeleted_success' => 'Действие успешно удалено!',
	'markDeleted_error' => 'Ошибка! Действие формы не удалено!',

	'copy_success' => 'Действие успешно скопировано!',
	'copy_error' => 'Ошибка! Действие формы не скопировано!',
	
	'show_form_action_menu_add_new_top' => 'Действие',
	
	'form_add_forms_event_title' => 'Добавление действия формы центра администрирования',
	'form_edit_forms_event_title' => 'Редактирование действия формы центра администрирования "%s"',

	'admin_form_tab_0' => 'Название',
	'confirm' => '<acronym title="Запрашивать подтверждение перед выполнением действия">Запрашивать подтверждение</acronym>',
	'name' => '<acronym title="Название функции-обработчика действия">Функция-обработчик</acronym>',
	'sorting' => 'Порядок сортировки',
	'picture' => '<acronym title="Изображение для действия в списке действий, например /admin/images/edit.gif">Изображение</acronym>',
	'icon' => '<acronym title="CSS-стиль пиктограммы для действия в списке действий, например fa fa-pencil">Пиктограмма</acronym>',
	'color' => '<acronym title="Название CSS-стиля, определяющего цвет действия в списке действий, например success">Цвет</acronym>',
	'dataset' => '<acronym title="Индекс набора данных, которым доступно действие (-1 — действие для всех наборов данных)">Индекс набора данных</acronym>',
	'single' => '<acronym title="Отображать действие в правом блоке со списком действий">Отображать в списке действий</acronym>',
	'group' => '<acronym title="Отображать действие в списке групповых операций">Групповая операция</acronym>',

	'admin_form_id' => 'Идентификатор формы центра администрирования',
	'id' => 'Идентификатор поля формы',
	
	'edit_success' => 'Действие формы добавлено!',
	'edit_error' => 'Ошибка! Действие формы не добавлено!',
	
	'form_event_menu_admin_form_action' => 'Список действий формы "%s"',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
);
